// SOI 2015 Creativity Task 'Bazaar'.
//
// Sample bot in Rust (rust-lang.org)
// Contact: sebastian@soi.ch

use std::io;
use std::rand::{task_rng, Rng};

// Read numbers from stdin.
fn get_input() -> Vec<uint> {
  let line = io::stdin().read_line().unwrap();
  return line.as_slice().trim().split(' ').filter_map(from_str).collect();
}

// Game configuration.
struct Bot {
  n: uint, a: uint, d: uint, g: uint
}

// Play a single auction.
fn play(bot: Bot) {
  let mut bids: Vec<uint> = Vec::from_elem(bot.d, 0u);
  let mut players: Vec<uint> = Vec::from_elem(bot.n, bot.g);
  let mut shaker = task_rng();

  // Distribute the available gold randomly.
  for _ in range(0u, bot.g ) {
    *bids.get_mut(shaker.gen_range(0u, bot.d)) += 1;
  }

  // Play the auction.
  for bid in bids.iter() {
    // Place the bid.  
    println!("{}", *bid);
    io::stdio::flush();

    // Keep track of every player's gold.
    *players.get_mut(0) -= *bid;  // Own player.
    for (p, v) in get_input().iter().enumerate() {
      *players.get_mut(p+1) -= *v;
    }
  }
}

fn main() {
  // Initialize bot.
  let config = get_input();
  let bot = Bot { n: config[0], a: config[1], d: config[2], g: config[3] };

  // Participate in the auctions.
  for _ in range(0u, bot.a) {
    play(bot);
  }
}
